@@ -14,6 +14,11 @@ urlpatterns = [
         views.remove_character,
         name="remove_character",
     ),
+    path(
+        "remove_admin_registered/<int:character_pk>/",
+        views.remove_admin_registered,
+        name="remove_admin_registered",
+    ),
     path(
         "remove_admin_character/<int:character_pk>/",
         views.remove_admin_character,
@@ -24,6 +29,11 @@ urlpatterns = [
         views.character_viewer,
         name="character_viewer",
     ),
+    path(
+        "purge_old_corphistory",
+        views.purge_old_corphistory,
+        name="purge_old_corphistory",
+    ),
     path(
         "char_mining_ledger_data/<int:character_pk>/",
         views.char_mining_ledger_data,
